Index: src/protocol/http/org/apache/jmeter/protocol/http/control/DNSCacheManager.java
===================================================================
--- src/protocol/http/org/apache/jmeter/protocol/http/control/DNSCacheManager.java	(revision 1654553)
+++ src/protocol/http/org/apache/jmeter/protocol/http/control/DNSCacheManager.java	(working copy)
@@ -42,7 +42,6 @@
 import org.xbill.DNS.Lookup;
 import org.xbill.DNS.Record;
 import org.xbill.DNS.Resolver;
-import org.xbill.DNS.SimpleResolver;
 import org.xbill.DNS.TextParseException;
 import org.xbill.DNS.Type;
 
@@ -104,11 +103,16 @@
         clone.cache = new LinkedHashMap<String, InetAddress[]>();
         CollectionProperty dnsServers = getServers();
         try {
-            clone.resolver = new ExtendedResolver();
+            String[] serverNames = new String[dnsServers.size()];
             PropertyIterator dnsServIt = dnsServers.iterator();
+            int index = 0;
             while (dnsServIt.hasNext()) {
-                String dnsServer = dnsServIt.next().getStringValue();
-                ((ExtendedResolver) clone.resolver).addResolver(new SimpleResolver(dnsServer));
+                serverNames[index] = dnsServIt.next().getStringValue();
+                index++;
+            }
+            clone.resolver = new ExtendedResolver(serverNames);
+            if (log.isDebugEnabled()) {
+                log.debug("Using DNS Resolvers: " + Arrays.asList(((ExtendedResolver) clone.resolver).getResolvers()));
             }
             // resolvers will be chosen via round-robin
             ((ExtendedResolver) clone.resolver).setLoadBalance(true);
@@ -146,13 +150,13 @@
      */
     private InetAddress[] requestLookup(String host) throws UnknownHostException {
         InetAddress[] addresses = null;
-        if (isCustomResolver() && ((ExtendedResolver) resolver).getResolvers().length > 1) {
+        if (isCustomResolver() && ((ExtendedResolver) resolver).getResolvers().length > 0) {
             try {
                 Lookup lookup = new Lookup(host, Type.A);
                 lookup.setCache(lookupCache);
                 lookup.setResolver(resolver);
                 Record[] records = lookup.run();
-                if (records.length == 0) {
+                if (records == null || records.length == 0) {
                     throw new UnknownHostException("Failed to resolve host name: " + host);
                 }
                 addresses = new InetAddress[records.length];
Index: test/src/org/apache/jmeter/protocol/http/control/TestDNSCacheManager.java
===================================================================
--- test/src/org/apache/jmeter/protocol/http/control/TestDNSCacheManager.java	(revision 0)
+++ test/src/org/apache/jmeter/protocol/http/control/TestDNSCacheManager.java	(revision 0)
@@ -0,0 +1,40 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements. See the NOTICE file distributed with this
+ * work for additional information regarding copyright ownership. The ASF
+ * licenses this file to You under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * 
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.jmeter.protocol.http.control;
+
+import java.net.UnknownHostException;
+import org.apache.jmeter.junit.JMeterTestCase;
+import org.junit.Test;
+
+public class TestDNSCacheManager extends JMeterTestCase {
+
+    @Test
+    public void testCloneWithCustomResolverAndInvalidNameserver() throws UnknownHostException {
+        DNSCacheManager original = new DNSCacheManager();
+        original.setCustomResolver(true);
+        original.addServer("127.0.0.99");
+        DNSCacheManager clone = (DNSCacheManager) original.clone();
+        try {
+            clone.resolve("jmeter.apache.org");
+            fail();
+        } catch (UnknownHostException e) {
+            // OK
+        }
+    }
+}
\ No newline at end of file

